# Tech Categories in the Reference Catalog
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/tech-categories-in-reference-catalog#overview)
  * [Exploring the TBM Taxonomy](https://help.sap.com/docs/leanix/ea/tech-categories-in-reference-catalog#exploring-the-tbm-taxonomy)
  * [Evaluating the TBM Taxonomy: Key Considerations](https://help.sap.com/docs/leanix/ea/tech-categories-in-reference-catalog#evaluating-the-tbm-taxonomy:-key-considerations)
  * [Importing Tech Categories from the Reference Catalog](https://help.sap.com/docs/leanix/ea/tech-categories-in-reference-catalog#importing-tech-categories-from-the-reference-catalog)


Tech categories in the reference catalog enable you to adopt the Technology Business Management (TBM) Taxonomy.
